Learn R Programming

guess (version 0.7.0)

dk_cell_probs: Cell probabilities for the model with Don't Know

Description

The multinomial cell probabilities implied by the latent class transition parameters, as in equation (2) of Cor and Sood. The nine latent transitions among guess (g), know (k) and don't know (d) are reduced to seven by the identifying assumption that people do not lose knowledge over the course of a short informative process: the know-to-guess and know-to-don't-know classes are identically zero and do not appear.

The seven remaining proportions sum to 1, and so do the nine cell probabilities returned here. Given those probabilities the parameters are recoverable in closed form -- gamma / (1 - gamma) is x10 / x00 -- with one over-identifying restriction left over, x1d / x0d = x10 / x00.

Usage

dk_cell_probs(gg, gk, gd, kk, dg, dk, dd, g1)

Value

numeric vector of length 9, ordered x00, x01, x0d, x10, x11, x1d, xd0, xd1, xdd

Arguments

gg

proportion guess -> guess

gk

proportion guess -> know

gd

proportion guess -> don't know

kk

proportion know -> know

dg

proportion don't know -> guess

dk

proportion don't know -> know

dd

proportion don't know -> don't know

g1

probability a guess is correct (gamma)