Creates one transition matrix per item and fits independent class proportions and guessing probabilities for every item.

item_lca_fit(
  pre_test,
  pst_test,
  na_as = c("dk", "missing"),
  missing_action = c("omit", "error"),
  ...
)

Arguments

pre_test

data.frame of pre-test responses

pst_test

data.frame of post-test responses

na_as

classification of NA responses

missing_action

structural missingness handling

...

passed to lca_cor()

Value

output from lca_cor()