Learn R Programming

guess (version 0.7.0)

cross_sectional_learning_score: Cross-Sectional Learning Score

Description

Applies the logistic function to the difference in cross-sectional logit scores. The result is bounded in [0, 1], but is not a calibrated probability of learning and is not an IRT estimate.

Usage

cross_sectional_learning_score(
  pre_test,
  pst_test,
  scale = 1,
  na_as = c("dk", "missing"),
  missing_action = c("omit", "error")
)

Value

numeric vector of learning scores in [0, 1]

Arguments

pre_test

data.frame of pre-test responses

pst_test

data.frame of post-test responses

scale

numeric scaling factor for the score difference (default 1)

na_as

classification of NA responses

missing_action

structural missingness handling

Examples

Run this code
sim <- simulate_lca(n = 100, gk = 0.30, seed = 123, return_classes = TRUE)
learning_score <- cross_sectional_learning_score(sim$pre, sim$post)
cor(learning_score, sim$learned)

Run the code above in your browser using DataLab