powered by
Applies the logistic function to the difference in cross-sectional logit scores. The result is bounded in [0, 1], but is not a calibrated probability of learning and is not an IRT estimate.
cross_sectional_learning_score( pre_test, pst_test, scale = 1, na_as = c("dk", "missing"), missing_action = c("omit", "error") )
numeric vector of learning scores in [0, 1]
data.frame of pre-test responses
data.frame of post-test responses
numeric scaling factor for the score difference (default 1)
classification of NA responses
structural missingness handling
sim <- simulate_lca(n = 100, gk = 0.30, seed = 123, return_classes = TRUE) learning_score <- cross_sectional_learning_score(sim$pre, sim$post) cor(learning_score, sim$learned)
Run the code above in your browser using DataLab