Adjusts observed 1s based on propensity to guess (based on observed 0s) and item level gamma. You can also put in your best estimate of hidden knowledge behind don't know responses.
pre data frame. Required. Each vector within the data frame should only take values 0, 1, and 'd'.
pst data frame. Required. Each vector within the data frame should only take values 0, 1, and 'd'.
probability of getting the right answer without knowledge
Numeric. Between 0 and 1. Hidden knowledge behind don't know responses. Default is .03.
Classification of NA responses: `"dk"` (the default) treats them as observed don't know responses; `"missing"` treats them as structural missingness.
How to handle structural missingness: `"omit"` excludes it and `"error"` rejects it.
nested list of pre and post adjusted responses, and adjusted learning estimates
pre_test_var <- data.frame(pre = c(1, 0, 0, 1, "d", "d", 0, 1, NA))
pst_test_var <- data.frame(pst = c(1, NA, 1, "d", 1, 0, 1, 1, "d"))
gamma <- c(.25)
group_adj(pre_test_var, pst_test_var, gamma)
#> $indiv
#> $indiv$pre_adj
#> pre
#> 1 0.6666667
#> 2 0.0000000
#> 3 0.0000000
#> 4 0.6666667
#> 5 0.0300000
#> 6 0.0300000
#> 7 0.0000000
#> 8 0.6666667
#> 9 0.0300000
#>
#> $indiv$pst_adj
#> pst
#> 1 0.9333333
#> 2 0.0300000
#> 3 0.9333333
#> 4 0.0300000
#> 5 0.9333333
#> 6 0.0000000
#> 7 0.9333333
#> 8 0.9333333
#> 9 0.0300000
#>
#>
#> $learn
#> pst
#> 0.2962963
#>