Learn R Programming

guess (version 0.7.0)

item_lca_fit: Fit Independent Item-Wise LCA Models

Description

Creates one transition matrix per item and fits independent class proportions and guessing probabilities for every item.

Usage

item_lca_fit(
  pre_test,
  pst_test,
  na_as = c("dk", "missing"),
  missing_action = c("omit", "error"),
  ...
)

Value

output from lca_cor()

Arguments

pre_test

data.frame of pre-test responses

pst_test

data.frame of post-test responses

na_as

classification of NA responses

missing_action

structural missingness handling

...

passed to lca_cor()