Creates one transition matrix per item and fits independent class proportions and guessing probabilities for every item.
item_lca_fit(
pre_test,
pst_test,
na_as = c("dk", "missing"),
missing_action = c("omit", "error"),
...
)output from lca_cor()
data.frame of pre-test responses
data.frame of post-test responses
classification of NA responses
structural missingness handling
passed to lca_cor()