guesstimate
transition matrix returned from multi_transmat
Optional. Vector of length 4. Priors for the parameters for model that fits data without Don't Knows
Optional. Vector of length 8. Priors for the parameters for model that fits data with Don't Knows
list with two items: parameter estimates and estimates of learning
# Without DK
pre_test <- data.frame(item1 = c(1, 0, 0, 1, 0), item2 = c(1, NA, 0, 1, 0))
pst_test <- pre_test + cbind(c(0, 1, 1, 0, 0), c(0, 1, 0, 0, 1))
transmatrix <- multi_transmat(pre_test, pst_test)
res <- lca_cor(transmatrix)